@@ -48,8 +48,8 @@ class BaseBehaviors(object):
         """
 
         if 'v3' in CONF.identity.auth_version.lower():
-            arg_list.extend(['--os-auth-url', CONF.identity.uri_v3])
-            arg_list.extend(['--os-project-name', CONF.keymanager.project_name])
+            arg_list.extend(['--os-project-name',
+                             CONF.keymanager.project_name])
             # NOTE(jaosorior): Should we add the user_domain_name to the
             #                  config?
             arg_list.extend(
@@ -59,10 +59,10 @@ class BaseBehaviors(object):
                  CONF.keymanager.project_domain_name])
             arg_list.extend(['--os-identity-api-version', '3'])
         else:
-            arg_list.extend(['--os-auth-url', CONF.identity.uri])
             arg_list.extend(['--os-tenant-name', CONF.keymanager.project_name])
             arg_list.extend(['--os-identity-api-version', '2.0'])
 
+        arg_list.extend(['--os-auth-url', CONF.identity.uri])
         arg_list.extend(['--os-username', CONF.keymanager.username,
                          '--os-password', CONF.keymanager.password])
 
@@ -125,7 +125,7 @@ class BaseBehaviors(object):
         """
         retval = []
         if str is not None and len(str) > 0:
-            rows = re.findall('\|(.*)?\n', str)
+            rows = re.findall('\|(.*?)\n', str)
             # Remove header
             header_row = rows.pop(0)
             key_names = re.findall('\s*(.*?)\s*\|', header_row)
